##  Step 2: Create a Tag Group for T-Shirt Sizes
Create a tag group with tags representing T-shirt sizes. You can do it in the application user interface (UI) or through the GraphQL API. To learn how to manage tag groups in the application UI, see [Tagging](https://help.sap.com/docs/leanix/ea/tagging?locale=en-US&state=PRODUCTION&version=CLOUD "This guide covers the essential steps for managing tags, including creating tag groups, adding and editing tags within those groups, and deleting tags and tag groups. Suggest Edits Introduction").
When creating a tag group, do the following:
  * Restrict the tag group to IT component fact sheets.
  * Set the group mode to Single.
